import React, { useContext, useEffect } from 'react';

import { DbContext } from '../../db/db-context-provider';
import { lat2tile, lon2tile } from '../../lib/geo';
import { zoom0 } from '../../store/map';

const Track: React.FC<{ track: any; id: string }> = (props) => {
  const dbContext = useContext(DbContext);

  useEffect(() => {
    const store = dbContext.tracksStore;
    const checkDb = async () => {
      store.getItem(props.id).then((value) => {
        if (value === null) {
          store.setItem(props.id, props.track).then((value) => {
            console.log(
              `Track ${props.id} saved in the ${store.driver()} Database.`
            );
          });
        }
      });
    };
    if (dbContext.ready) {
      checkDb();
    }
  }, [dbContext, props]);

  const trkseg = props.track.track.trk[0].trkseg[0];
  const d = trkseg.trkpt.reduce(
    (previous: string, current: any, index: number) => {
      const action = index === 0 ? 'M' : index === 1 ? 'L' : '';
      return `${previous} ${action} ${lon2tile(
        current.$.lon,
        zoom0
      )}, ${lat2tile(current.$.lat, zoom0)}`;
    },
    ''
  );

  return <path d={d} className='track' />;
};

export default Track;
