import react, { useEffect, useState } from 'react';

import * as CordovaSQLiteDriver from 'localforage-cordovasqlitedriver';
import localforage from 'localforage';

const initialDbContext = { ready: false, tracksStore: localforage };
export const DbContext = react.createContext(initialDbContext);

const DbContextProvider: react.FC<{
  children?: JSX.Element;
}> = (props: { children?: JSX.Element }) => {
  const [store, setStore] = useState(localforage);
  const [ready, setReady] = useState(false);

  useEffect(() => {
    const config = {
      name: 'dyomedea',
      driver: [
        CordovaSQLiteDriver._driver,
        localforage.INDEXEDDB,
        localforage.WEBSQL,
        localforage.LOCALSTORAGE,
      ],
    };
    const newStore = localforage.createInstance({
      storeName: 'tracks',
      ...config,
    });
    setStore(newStore);
    setReady(true);
  }, []);

  return (
    <DbContext.Provider value={{ ready, tracksStore: store }}>
      {props.children}
    </DbContext.Provider>
  );
};

export default DbContextProvider;
